# Generated by Django 3.0.4 on 2020-04-27 13:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0003_auto_20200426_1820'),
    ]

    operations = [
        migrations.AddField(
            model_name='kunde',
            name='zusammenfuegen',
            field=models.ForeignKey(blank=True, help_text='Dies kann nicht widerrufen werden! Werte in diesem Kunden werden bevorzugt.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='kmuhelper.Kunde', verbose_name='Zusammenfügen mit'),
        ),
    ]
